package utils

import (
	"fmt"
	"os"
)

// CreateDirectory 尝试创建指定路径的文件夹
// 如果文件夹已存在，则返回错误
func CreateDirectory(path string) error {
	// 使用 os.Stat 检查文件夹是否存在
	_, err := os.Stat(path)
	if err == nil {
		// 如果文件夹已存在，返回自定义错误
		return fmt.Errorf("目录 %s 已存在", path)
	}

	// 如果错误不是 "文件不存在"，则返回该错误
	if !os.IsNotExist(err) {
		return err
	}

	// 如果文件夹不存在，创建文件夹
	err = os.Mkdir(path, 0755) // 0755 表示文件夹权限
	if err != nil {
		return fmt.Errorf("创建目录 %s 失败: %v", path, err)
	}

	return nil
}


